@@ -415,8 +415,10 @@ def create_pfile(output_filename, feature_count, data):
     :param data: list of (x, y) tuples, where x is the feature vector
                  of dimension ``feature_count`` and y is a label.
     """
-    f = tempfile.NamedTemporaryFile()
-    input_filename = f.name
+    #f = tempfile.NamedTemporaryFile()
+    #input_filename = f.name
+    input_filename = "tmp.pfile"
+    f = open(input_filename)
 
     for symbolnr, instance in enumerate(data):
         feature_string, label = instance
@@ -430,7 +432,11 @@ def create_pfile(output_filename, feature_count, data):
     command = "pfile_create -i %s -f %i -l 1 -o %s" % \
               (input_filename, feature_count, output_filename)
     logging.info(command)
-    os.system(command)
+    return_code = os.system(command)
+    if return_code != 0:
+        logging.error("pfile_create failed with return code %i." % return_code)
+        sys.exit(-1)
+    f.close()
 
 
 def get_recognizer_folders(model_folder):
